# Course Description

In this course at TTLMakerspace, you will go from beginner to a practical working knowledge of CAD modelling and CNC machining with an automated milling machine.

Starting with desktop versions of CNC machines, you’ll work your way through lessons up to the industrial Omni 1350 6’ x 8’ CNC milling machine.

Schedule:
Six three-hour weekly classes, Thursdays 6pm to 9pm

or

Saturdays 1:30pm to 4:30pm

## Outcomes:
At the end of this course you will have achieved the following goals:
* A complete understanding of the steps needed to go from concept to completed part
* Familiarity with the properties of a variety of materials - woods, plastics, composites
* Experience and comprehension of the most important principles of CAD modeling
* Selecting and programming the most commonly used tools
* Full understanding of the most common machining operations
* Experience creating tool paths with CAM software
* Setting up a CNC mill and performing operations
* Machine maintenance and Safety

Following this course, you’ll be certified to use desktop mills, and book time with the industrial mill at TTLMakerspace (with your membership). You will also be able to join the growing community of TTL Makers sharing CNC knowledge on our Discord community.

Useful for: furniture, cabinets, flat-pack, instruments, desktops, mechanical parts, boats, engraved signs

# What To Expect

## Week 1 - Manual Control

* Get to know the available resources
* Learn the parts of CNC machines and understand their capabilities. 
* Practice manually controlling both the mini CNC and the full-sized Omni CNC.
* Practice setting up a job and manually milling it.

![Week1](./class1.png)

**Exercise - Milling Practice**

Using the mini-mills, learn to set up a machine for proper milling. Repeat this on the large machine, and manually control the machine for your first milling operation.

---
## Week 2 - Creating Automation, Tool Changes

* Starting on the mini-mill, learn to cut with Gcode files
* Understand the full workflow for designing an item, and creating automation to produce it on a CNC machine.
* Introduction to CAD and CAM

![Week2 ](./TorontoTheGood.png)

**In-Class Exercise - Toronto The Good**

Starting with a provided model, learn to calibrate the machine, run a gcode file with sending software. Do essential tool-change operations.

Next, Starting from basic specifications, design the disc in CAD, then create the cutting paths in CAM.

---
## Week 3 - Multi Materials and Automation

* On the big mill, learn to cut hardwood
* Understanding material differences, bit selection
* Designing for milling - filets, chamfers, holes
* Tags and Dressups

![TrinketBox](./class3.png)

**Exercise - Jewelrybox**

Learn to plan the ordering of operations. Learn how to use manual control to override the functioning automation.

**Homework Assignment #1 - Game Piece**

Given a model, generate the cam paths necessary to produce the piece on a milling machine.

---
## Week 4 - Surfacing In-Depth

* Three types of surfacing - facing, etching, 3D contouring
* Learn to work with 2D and 3D models

![Class4](./class4.png)
**Exercise - Face Milling**

Create a parametric file useful for milling surfaces of any size.

**Exercise - Pen Case**

Learn to use engraving techniques for surface features such as inlays, chamfers, rabbets, and corner-rounding

**Exercise - Architectural Model**

Learn to work with 3D Contours in a simple simulation of work for an Architecural project.

---
## Week 5 - Using Design Tools

* Learn to incorporate files made in design tools like Inkscape into CAD
* Work with text in CAD
* Work with Vector files (Illustrator, Inkscape)
* Work with STEP files (Rhino, Fusion 360, Solidworks)

![Class5](./class5.png)

**Exercise - TTL Sign**

Learn how to prepare interchange files for success in CNC milling. Create and cut the TTL sign by working with SVG files.

**Exercise - Dice Tray**

Given a dice-tray model created in Fusion, create the CAM paths necessary to cut it out with the Omni mill using FreeCAD.

---
## Week 6 - Multi-body Construction

Learn to design and mill interlocking parts
Use Construction Geometry
Understand sub-shape binders

![Class 6](./class6.png)
### Final Assignment - Cleat Wall Organizer

Using what you have learned and a template, create a cleat-wall organizer that you’ll be able to arrange and mill on your own. Book a time to review and cut the assignment!

### During the program:

To complete the program, you must complete all assignments and demonstrate proficiency.
Make arrangements to catch up missed classes.
Use the small machines to practice (subject to availability/classes)
Following week 3, you can practice on the big CNC with supervision (subject to availability)
If you hit a snag, let me know!

### Following the program:

* Three hours of free CNC time (no membership required, must be used within six weeks)

* With membership, can use small machines at any time.
* Members book time on large CNC through Cobot, $25/hr
* Must use approved software for path creation
* Run your file by us to avoid disappointment!


### Tips For Success:

* Practice! Use the small machines.
* Make your own files
* Have a project in mind, but don’t miss important concepts by being focus-locked on it.

### Resources:

[Youtube Playlist](https://www.youtube.com/playlist?list=PLWmF8yQa3itOntkOny9doHqQwAZ0soRrS)

[Omni CNC Quickstart](./docs/CNC_Milling_Beast_Mode.pdf)